@@ -131,7 +131,7 @@ typedef void builtinserviceexec_fnt(const char *const *args);
 builtinserviceexec_fnt NONRETURNING bisexec_environment, bisexec_parameter;
 builtinserviceexec_fnt NONRETURNING bisexec_version, bisexec_help;
 builtinserviceexec_fnt NONRETURNING bisexec_toplevel, bisexec_override, bisexec_reset;
-builtinserviceexec_fnt NONRETURNING bisexec_execute;
+builtinserviceexec_fnt NONRETURNING bisexec_execute, bisexec_shutdown;
 extern const char *const builtinservicehelpstrings[];
 
 void execservice(const int synchsocket[], int clientfd) NONRETURNING;
